@@ -69,10 +69,10 @@ static void Rjpeg_fin(SEXP dco) {
         free(cinfo);
     }
     /* make it a NULL ptr in case this was not a finalizer call */
-    CAR(dco) = 0;
+    R_ClearExternalPtr(dco);
 }
 
-static struct jpeg_error_mgr *Rjpeg_new_err() {
+static struct jpeg_error_mgr *Rjpeg_new_err(void) {
     struct jpeg_error_mgr *jerr = (struct jpeg_error_mgr*) calloc(sizeof(struct Rjpeg_error_mgr), 1);
     if (!jerr) Rf_error("Unable to allocate jpeg error management structure");
     jpeg_std_error(jerr);
